==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/AggregatedDataProviderLayerInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { List$1 } from "./List$1";
import { SummaryOperand_$type } from "./SummaryOperand";
/**
 * @hidden
 */
var AggregatedDataProviderLayerInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AggregatedDataProviderLayerInfo, _super);
    function AggregatedDataProviderLayerInfo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.f = new List$1(String_$type, 0);
        _this.e = new List$1(String_$type, 0);
        _this.h = new List$1(Base.$, 0);
        _this.g = new List$1(SummaryOperand_$type, 0);
        _this.b = new List$1(String_$type, 0);
        _this.c = new List$1(Base.$, 0);
        _this.d = new List$1(Base.$, 0);
        return _this;
    }
    AggregatedDataProviderLayerInfo.prototype.p = function (a, b, c, d) {
        this.m.add(a);
        this.l.add(b);
        this.n.add(c);
        this.o.add1(d);
    };
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "a", {
        get: function () {
            return this.i != null && this.i.count == 1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "m", {
        get: function () {
            return this.f;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "l", {
        get: function () {
            return this.e;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "o", {
        get: function () {
            return this.h;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "n", {
        get: function () {
            return this.g;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "i", {
        get: function () {
            return this.b;
        },
        set: function (a) {
            this.b = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "j", {
        get: function () {
            return this.c;
        },
        set: function (a) {
            this.c = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "k", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
        },
        enumerable: true,
        configurable: true
    });
    AggregatedDataProviderLayerInfo.$t = markType(AggregatedDataProviderLayerInfo, 'AggregatedDataProviderLayerInfo');
    return AggregatedDataProviderLayerInfo;
}(Base));
export { AggregatedDataProviderLayerInfo };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/AggregatedDataProviderLayerInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { List$1 } from "./List$1";
import { DataSourceSummaryOperand_$type } from "./DataSourceSummaryOperand";
/**
 * @hidden
 */
var AggregatedDataProviderLayerInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AggregatedDataProviderLayerInfo, _super);
    function AggregatedDataProviderLayerInfo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.f = new List$1(String_$type, 0);
        _this.e = new List$1(String_$type, 0);
        _this.h = new List$1(Base.$, 0);
        _this.g = new List$1(DataSourceSummaryOperand_$type, 0);
        _this.b = new List$1(String_$type, 0);
        _this.c = new List$1(Base.$, 0);
        _this.d = new List$1(Base.$, 0);
        return _this;
    }
    AggregatedDataProviderLayerInfo.prototype.p = function (a, b, c, d) {
        this.m.add(a);
        this.l.add(b);
        this.n.add(c);
        this.o.add1(d);
    };
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "a", {
        get: function () {
            return this.i != null && this.i.count == 1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "m", {
        get: function () {
            return this.f;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "l", {
        get: function () {
            return this.e;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "o", {
        get: function () {
            return this.h;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "n", {
        get: function () {
            return this.g;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "i", {
        get: function () {
            return this.b;
        },
        set: function (a) {
            this.b = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "j", {
        get: function () {
            return this.c;
        },
        set: function (a) {
            this.c = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AggregatedDataProviderLayerInfo.prototype, "k", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
        },
        enumerable: true,
        configurable: true
    });
    AggregatedDataProviderLayerInfo.$t = markType(AggregatedDataProviderLayerInfo, 'AggregatedDataProviderLayerInfo');
    return AggregatedDataProviderLayerInfo;
}(Base));
export { AggregatedDataProviderLayerInfo };
